pub struct PreciseNumber {
pub val: U256,
}Expand description
Struct encapsulating a fixed-point number that allows for decimal calculations
Fields
val: U256Wrapper over the inner value, which is multiplied by ONE
Implementations
Sourceimpl PreciseNumber
impl PreciseNumber
pub fn zero() -> Self
pub fn one() -> Self
Sourcepub fn new(val: u128) -> Result<Self>
pub fn new(val: u128) -> Result<Self>
Create a precise number from an imprecise u128, should always succeed
Sourcepub fn from_decimal(decimal: u128, exponent: i32) -> Result<Self>
pub fn from_decimal(decimal: u128, exponent: i32) -> Result<Self>
Create a precise number from a decimal number using exponent to adjust precision.
Sourcepub fn to_imprecise(&self) -> Result<u128>
pub fn to_imprecise(&self) -> Result<u128>
Convert a precise number back to u128
Sourcepub fn to_imprecise_u64(&self) -> Result<u64>
pub fn to_imprecise_u64(&self) -> Result<u64>
Convert a precise number back to u64
pub fn mul_up(self, rhs: Self) -> Result<Self>
pub fn div_up(self, rhs: Self) -> Result<Self>
Sourcepub fn almost_eq(&self, rhs: &Self, precision: U256) -> bool
pub fn almost_eq(&self, rhs: &Self, precision: U256) -> bool
Checks that two PreciseNumbers are equal within Ok tolerance
Sourcepub fn greater_than(&self, rhs: &Self) -> bool
pub fn greater_than(&self, rhs: &Self) -> bool
Checks that a number is greater than another
Sourcepub fn less_than_or_equal(&self, rhs: &Self) -> bool
pub fn less_than_or_equal(&self, rhs: &Self) -> bool
Checks that a number is less than another
Sourcepub fn greater_than_or_equal(&self, rhs: &Self) -> bool
pub fn greater_than_or_equal(&self, rhs: &Self) -> bool
Checks that a number is greater than another
Sourcepub fn checked_div(&self, rhs: &Self) -> Result<Self>
pub fn checked_div(&self, rhs: &Self) -> Result<Self>
Performs a checked division on two precise numbers
Sourcepub fn checked_mul(&self, rhs: &Self) -> Result<Self>
pub fn checked_mul(&self, rhs: &Self) -> Result<Self>
Performs a multiplication on two precise numbers
Sourcepub fn checked_add(&self, rhs: &Self) -> Result<Self>
pub fn checked_add(&self, rhs: &Self) -> Result<Self>
Performs addition of two precise numbers
Sourcepub fn checked_sub(&self, rhs: &Self) -> Result<Self>
pub fn checked_sub(&self, rhs: &Self) -> Result<Self>
Subtracts the argument from self
Sourcepub fn unsigned_sub(&self, rhs: &Self) -> (Self, bool)
pub fn unsigned_sub(&self, rhs: &Self) -> (Self, bool)
Performs a subtraction, returning the result and whether the result is negative
Sourcepub fn checked_pow(&self, exponent: u128) -> Result<Self>
pub fn checked_pow(&self, exponent: u128) -> Result<Self>
Performs pow on a precise number